;; Generated package description from posframe.el  -*- no-byte-compile: t -*-
(define-package "posframe" "0.8.8.0.20210311.93757" "Pop a posframe (just a frame) at point" '((emacs "26")) :keywords '("convenience" "tooltip") :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :url "https://github.com/tumashu/posframe")
